# TCGen

Test cases generator generator tool. The first sentence has no typo.
Given a set of strings create a code that randomly generate samples from the same distribution of such strings.
It is highly focused for test cases in competitive programming problems but can be used/extended beyond this scope.

## Usage

`python3 -m tcgen --path /path/to/testcases`
